@@ -19,9 +19,9 @@ class Jobs(object):
         self.client = RestClient(jwt=token, telemetry=telemetry)
 
     def _url(self, path=None):
-        url = 'https://%s/api/v2/jobs' % self.domain
+        url = 'https://{}/api/v2/jobs'.format(self.domain)
         if path is not None:
-            return url + '/' + path
+            return '{}/{}'.format(url, path)
         return url
 
     def get(self, id):
@@ -29,6 +29,8 @@ class Jobs(object):
 
         Args:
             id (str): The id of the job.
+
+        See: https://auth0.com/docs/api/management/v2#!/Jobs/get_jobs_by_id
         """
         return self.client.get(self._url(id))
 
@@ -37,10 +39,23 @@ class Jobs(object):
 
         Args:
             id (str): The id of the job.
+
+        See: https://auth0.com/docs/api/management/v2#!/Jobs/get_errors
         """
-        url = self._url('%s/errors' % (id))
+        url = self._url('{}/errors'.format(id))
         return self.client.get(url)
 
+    def export_users(self, body):
+        """Export all users to a file using a long running job.
+
+        Check job status with get(). URL pointing to the export file will be
+        included in the status once the job is complete.
+
+        Args:
+            body (dict): Please see: https://auth0.com/docs/api/management/v2#!/Jobs/post_users_exports
+        """
+        return self.client.post(self._url('users-exports'), data=body)
+
     def import_users(self, connection_id, file_obj, upsert=False):
         """Imports users to a connection from a file.
 
@@ -50,6 +65,8 @@ class Jobs(object):
 
             file_obj (file): A file-like object to upload. The format for
                 this file is explained in: https://auth0.com/docs/bulk-import
+
+        See: https://auth0.com/docs/api/management/v2#!/Jobs/post_users_imports
         """
         return self.client.file_post(self._url('users-imports'),
                                      data={'connection_id': connection_id, 'upsert': str(upsert).lower()},
